==> service_client-0.0.4-20211014.015544-7-sources.jar: com/northpool/service/config/style/StyleBean.java <==
package com.northpool.service.config.style;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.annotation.JSONField;
import com.northpool.service.config.serializer.BinaryValueDeserializer;
import com.northpool.service.config.serializer.BinaryValueSerializer;

public class StyleBean {

    protected String uuid;

    protected String name;

    protected String ownServer;

    protected String styleJson;

    protected String[] textureLabel;

    protected String[] textureLayer;

    protected String[] extFonts;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] styleLayerJs;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] styleLabelJs;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] styleAvoidjs;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] queryLayer;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] queryLabel;

    protected String version;

    protected Boolean isTmp;

    protected Double xmin;

    protected Double ymin;

    protected Double xmax;

    protected Double ymax;

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getStyleJson() {
        return styleJson;
    }

    public void setStyleJson(String styleJson) {
        this.styleJson = styleJson;
    }

    public byte[] getStyleLayerJs() {
        return styleLayerJs;
    }

    public void setStyleLayerJs(byte[] styleLayerJs) {
        this.styleLayerJs = styleLayerJs;
    }

    public byte[] getStyleLabelJs() {
        return styleLabelJs;
    }

    public void setStyleLabelJs(byte[] styleLabelJs) {
        this.styleLabelJs = styleLabelJs;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getOwnServer() {
        return ownServer;
    }

    public void setOwnServer(String ownServer) {
        this.ownServer = ownServer;
    }

    public byte[] getStyleAvoidjs() {
        return styleAvoidjs;
    }

    public void setStyleAvoidjs(byte[] styleAvoidjs) {
        this.styleAvoidjs = styleAvoidjs;
    }

    public Boolean getTmp() {
        return isTmp;
    }

    public void setTmp(Boolean tmp) {
        isTmp = tmp;
    }

    public String[] getTextureLabel() {
        return textureLabel;
    }

    public void setTextureLabel(String[] textureLabel) {
        this.textureLabel = textureLabel;
    }

    public String[] getTextureLayer() {
        return textureLayer;
    }

    public void setTextureLayer(String[] textureLayer) {
        this.textureLayer = textureLayer;
    }

    public String[] getExtFonts() {
        return extFonts;
    }

    public void setExtFonts(String[] extFonts) {
        this.extFonts = extFonts;
    }

    public byte[] getQueryLayer() {
        return queryLayer;
    }

    public void setQueryLayer(byte[] queryStyle) {
        this.queryLayer = queryStyle;
    }

    public byte[] getQueryLabel() {
        return queryLabel;
    }

    public void setQueryLabel(byte[] queryLabel) {
        this.queryLabel = queryLabel;
    }

    public String toJson(){
        return JSON.toJSONString(this);
    }

    public Double getXmin() {
        return xmin;
    }

    public void setXmin(Double xmin) {
        this.xmin = xmin;
    }

    public Double getYmin() {
        return ymin;
    }

    public void setYmin(Double ymin) {
        this.ymin = ymin;
    }

    public Double getXmax() {
        return xmax;
    }

    public void setXmax(Double xmax) {
        this.xmax = xmax;
    }

    public Double getYmax() {
        return ymax;
    }

    public void setYmax(Double ymax) {
        this.ymax = ymax;
    }
}

==> service_client-0.0.4-20220215.030001-26-sources.jar: com/northpool/service/config/style/StyleBean.java <==
package com.northpool.service.config.style;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.annotation.JSONField;
import com.northpool.service.config.serializer.BinaryValueDeserializer;
import com.northpool.service.config.serializer.BinaryValueSerializer;

public class StyleBean {

    protected String uuid;

    protected String name;

    protected String ownServer;

    protected String styleJson;

    protected String[] textureLabel;

    protected String[] textureLayer;

    protected String[] extFonts;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] styleLayerJs;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] styleLabelJs;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] styleAvoidjs;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] queryLayer;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] queryLabel;

    @JSONField(deserializeUsing = BinaryValueDeserializer.class,serializeUsing = BinaryValueSerializer.class)
    protected byte[] mapboxStyle;

    protected String version;

    protected Boolean isTmp;

    protected Double xmin;

    protected Double ymin;

    protected Double xmax;

    protected Double ymax;

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getStyleJson() {
        return styleJson;
    }

    public void setStyleJson(String styleJson) {
        this.styleJson = styleJson;
    }

    public byte[] getStyleLayerJs() {
        return styleLayerJs;
    }

    public void setStyleLayerJs(byte[] styleLayerJs) {
        this.styleLayerJs = styleLayerJs;
    }

    public byte[] getStyleLabelJs() {
        return styleLabelJs;
    }

    public void setStyleLabelJs(byte[] styleLabelJs) {
        this.styleLabelJs = styleLabelJs;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getOwnServer() {
        return ownServer;
    }

    public void setOwnServer(String ownServer) {
        this.ownServer = ownServer;
    }

    public byte[] getStyleAvoidjs() {
        return styleAvoidjs;
    }

    public void setStyleAvoidjs(byte[] styleAvoidjs) {
        this.styleAvoidjs = styleAvoidjs;
    }

    public Boolean getTmp() {
        return isTmp;
    }

    public void setTmp(Boolean tmp) {
        isTmp = tmp;
    }

    public String[] getTextureLabel() {
        return textureLabel;
    }

    public void setTextureLabel(String[] textureLabel) {
        this.textureLabel = textureLabel;
    }

    public String[] getTextureLayer() {
        return textureLayer;
    }

    public void setTextureLayer(String[] textureLayer) {
        this.textureLayer = textureLayer;
    }

    public String[] getExtFonts() {
        return extFonts;
    }

    public void setExtFonts(String[] extFonts) {
        this.extFonts = extFonts;
    }

    public byte[] getQueryLayer() {
        return queryLayer;
    }

    public void setQueryLayer(byte[] queryStyle) {
        this.queryLayer = queryStyle;
    }

    public byte[] getQueryLabel() {
        return queryLabel;
    }

    public void setQueryLabel(byte[] queryLabel) {
        this.queryLabel = queryLabel;
    }

    public String toJson(){
        return JSON.toJSONString(this);
    }

    public Double getXmin() {
        return xmin;
    }

    public void setXmin(Double xmin) {
        this.xmin = xmin;
    }

    public Double getYmin() {
        return ymin;
    }

    public void setYmin(Double ymin) {
        this.ymin = ymin;
    }

    public Double getXmax() {
        return xmax;
    }

    public void setXmax(Double xmax) {
        this.xmax = xmax;
    }

    public Double getYmax() {
        return ymax;
    }

    public void setYmax(Double ymax) {
        this.ymax = ymax;
    }

    public byte[] getMapboxStyle() {
        return mapboxStyle;
    }

    public void setMapboxStyle(byte[] mapboxStyle) {
        this.mapboxStyle = mapboxStyle;
    }
}
